summaryrefslogtreecommitdiff
path: root/rules.js
diff options
context:
space:
mode:
Diffstat (limited to 'rules.js')
-rw-r--r--rules.js5
1 files changed, 2 insertions, 3 deletions
diff --git a/rules.js b/rules.js
index 8990e3c..11d2211 100644
--- a/rules.js
+++ b/rules.js
@@ -479,7 +479,6 @@ exports.view = function (state, player) {
}
}
return view
- console.log('view', view)
}
// === ACTIONS ===========
@@ -6604,10 +6603,10 @@ states.vm_support_check_prep = {
game.selected_space = space
// Check for Austria-Hungary Border Reopened - check on first Support Check only
// First check for Monday Demonstrations - Support Checks will always be in East Germany
// TODO: Add check for My First Banana?
if (
- game.vm_event === C_THE_MONDAY_DEMONSTRATIONS &&
+ (game.vm_event === C_THE_MONDAY_DEMONSTRATIONS || game.vm_event === C_MY_FIRST_BANANA) &&
game.persistent_events.includes(C_AUSTRIA_HUNGARY_BORDER_REOPENED)
) {
game.austria_hungary_border_reopened_tracker = true
@@ -6604,10 +6603,10 @@ states.vm_support_check_prep = {
game.selected_space = space
// Check for Austria-Hungary Border Reopened - check on first Support Check only
- // First check for Monday Demonstrations - Support Checks will always be in East Germany
+ // First check for Monday Demonstrations or My First Banana - Support Checks will always be in East Germany
// TODO: Add check for My First Banana?
if (